(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     11131,        476]*)
(*NotebookOutlinePosition[     11975,        503]*)
(*  CellTagsIndexPosition[     11931,        499]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Chapter 1: Introduction to Software", "Section"],

Cell[TextData[{
  "The main purpose of this section is to give you a chance to practice using\
\nMathematica. It has several functions which are relevant to this section. \n\
For making computations in the integers modulo",
  StyleBox[" n",
    FontWeight->"Bold"],
  " there is a built-in function \n",
  StyleBox["Mod",
    FontWeight->"Bold"],
  ". Thus"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mod[25 + 87, \ 13]\)], "Input"],

Cell[BoxData[
    \(8\)], "Output"]
}, Open  ]],

Cell[TextData[StyleBox["and",
  FontSize->12]], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mod[21*86, \ 17]\)], "Input"],

Cell[BoxData[
    \(4\)], "Output"]
}, Open  ]],

Cell[TextData[StyleBox["and",
  FontSize->12]], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mod[2^12, \ 7]\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["A more efficient way of computing powers  mod n",
    FontSize->12],
  StyleBox[" ",
    FontFamily->"cmti12",
    FontSize->12],
  StyleBox["is to use the function ",
    FontSize->12],
  StyleBox["PowerMod",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox[":",
    FontSize->12]
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(PowerMod[2, \ 12, \ 7]\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "For any real number ",
  StyleBox["a",
    FontWeight->"Bold"],
  " the function  ",
  StyleBox["N[a, m]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "will compute ",
  StyleBox["a",
    FontWeight->"Bold"],
  " to ",
  StyleBox["m",
    FontWeight->"Bold"],
  " digits. For example,"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[1/7, \ 20]\)], "Input"],

Cell[BoxData[
    \(0.14285714285714285714285714285534`20\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "So we see that the period of ",
  StyleBox["1/7",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" ",
    FontWeight->"Bold"],
  "is 1,4,2,8,5,7,  as discussed above. Similarly"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[1/19, \ 40]\)], "Input"],

Cell[BoxData[
    \(0.0526315789473684210526315789473684210526315789473684`40\)], "Output"]
}, Open  ]],

Cell["\<\
Thus the period of  1/19 is  0,5,2,6,3,1,5,7,8,9,4,7,3,6,8,4,2,1 , \
which has length 18 . And\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mod[10^18\  - \ 1, \ 19]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "but for smaller k,  ",
  Cell[BoxData[
      \(TraditionalForm\`10\^k\)]],
  " - 1 \[NotCongruent] 0 ",
  StyleBox["mod 19",
    FontSlant->"Italic"],
  ". We can do these calculations for all the primes less than 30 say, \nand \
tabulate the results. They confirm Theorem 1.3."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[{{"\<prime\>", 3, 7, 11, 13, 17, 19, 23, 
          29}, \[IndentingNewLine]{"\<period\>", 2, 6, 2, 6, 16, 18, 22, 
          28}, \[IndentingNewLine]{"\<k\>", 2, 6, 2, 6, 16, 18, 22, 
          28}}]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"prime\"\>", "3", "7", "11", "13", "17", "19", "23", "29"},
          {"\<\"period\"\>", "2", "6", "2", "6", "16", "18", "22", "28"},
          {"\<\"k\"\>", "2", "6", "2", "6", "16", "18", "22", "28"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["Interestingly", "Text"],

Cell[TextData[{
  "1001 = ",
  Cell[BoxData[
      \(TraditionalForm\`10\^3\)]],
  " + 1 = 7\[CenterDot]11\[CenterDot]13 ,"
}], "Text",
  TextAlignment->Center],

Cell["so that", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`10\^3\)]],
  " + 1 \[Congruent] 0  mod 7 ."
}], "Text",
  TextAlignment->Center],

Cell["Similarly,", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mod[10^9\  + \ 1, \ 19]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell["\<\
What do you think is going on? Experiment a bit and try to make a \
conjecture.
\
\>", "Text"],

Cell[TextData[{
  StyleBox["\tGiven a pair of relatively prime integers ",
    FontSize->12],
  StyleBox["a",
    FontFamily->"cmti12"],
  StyleBox["  and ",
    FontSize->12],
  StyleBox["b",
    FontFamily->"cmti12"],
  StyleBox[" ",
    FontSize->12,
    FontSlant->"Italic"],
  StyleBox[", the function",
    FontSize->12],
  StyleBox[" ",
    FontFamily->"Courier",
    FontSize->12],
  StyleBox["ExtendedGCD",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox[" will compute integers ",
    FontSize->12],
  StyleBox["s",
    FontFamily->"cmti12"],
  StyleBox["  and",
    FontSize->12],
  StyleBox[" ",
    FontSize->12,
    FontSlant->"Italic"],
  StyleBox["t",
    FontFamily->"cmti12"],
  StyleBox[" ",
    FontSize->12,
    FontSlant->"Italic"],
  StyleBox[" so that  ",
    FontSize->12],
  StyleBox["1 = as + bt",
    FontFamily->"cmti12"],
  StyleBox[" ",
    FontFamily->"cmbx12"],
  StyleBox[". For example,",
    FontSize->12]
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExtendedGCD[57, \ 21]\)], "Input"],

Cell[BoxData[
    \({3, {3, \(-8\)}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This means that   3 = 3",
  StyleBox["\[CenterDot]",
    FontFamily->"Courier",
    FontSlant->"Italic"],
  "57 - 8",
  StyleBox["\[CenterDot]",
    FontFamily->"Courier",
    FontSlant->"Italic"],
  "21 . If we want to find the multiplicative\ninverse of 105",
  StyleBox[" ",
    FontSize->12],
  "in ",
  StyleBox[" ",
    FontSize->12],
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalF]\_197\)],
    FontSize->12],
  ", we can enter"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExtendedGCD[105, \ 197]\)], "Input"],

Cell[BoxData[
    \({1, {\(-15\), 8}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["So  1  =  -15 \[CenterDot] 105 + 8 \[CenterDot] 197",
    FontSize->12],
  " ",
  StyleBox[", and  -15 = 182  is the multiplicative inverse of 105 .\n\n\tIn \
the package NumberTheory`NumberTheoryFunctions` there is a function called ",
    FontSize->12],
  StyleBox["ChineseRemainderTheorem",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox["  which will solve two such congruences simultaneously - in fact \
it will solve a system:",
    FontSize->12]
}], "Text",
  TextAlignment->Left,
  FontSize->14],

Cell[TextData[{
  "\t\n",
  StyleBox["x \[Congruent] ",
    FontSize->12],
  Cell[BoxData[
      \(TraditionalForm\`b\_1\)],
    FontSize->12],
  StyleBox[" (mod ",
    FontSize->12],
  Cell[BoxData[
      \(TraditionalForm\`n\_1\)],
    FontSize->12],
  StyleBox[")\n\n\[VerticalEllipsis]\n\nx \[Congruent] ",
    FontSize->12],
  Cell[BoxData[
      \(TraditionalForm\`b\_r\)],
    FontSize->12],
  StyleBox[" (mod ",
    FontSize->12],
  Cell[BoxData[
      \(TraditionalForm\`n\_r\)],
    FontSize->12],
  StyleBox[")",
    FontSize->12]
}], "Text",
  TextAlignment->Center,
  FontSize->14],

Cell["To use it you first load the package:", "Text"],

Cell[BoxData[
    \(<< NumberTheory`NumberTheoryFunctions`\)], "Input"],

Cell[TextData[{
  "\n",
  StyleBox["Then you simply enter",
    FontFamily->"Times",
    FontSize->12],
  StyleBox["\n\n\t",
    FontSize->12],
  Cell[BoxData[
      FormBox[
        StyleBox[
          FormBox[
            RowBox[{"\t", 
              RowBox[{"ChineseRemainderTheorem", "[", 
                RowBox[{"{", 
                  SubscriptBox[
                    StyleBox["b",
                      FontSlant->"Plain"], "1"]}]}]}],
            "TraditionalForm"],
          FontFamily->"Courier",
          FontSize->12,
          FontWeight->"Bold"], TraditionalForm]],
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox[", \[CenterEllipsis],",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox[" ",
    FontSize->12],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["b",
            FontSlant->"Plain"], "r"], TraditionalForm]],
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox["}, ",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox["{",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["n",
            FontSlant->"Plain"], "1"], TraditionalForm]],
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox[", \[CenterEllipsis], ",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["n",
            FontSlant->"Plain"], "r"], TraditionalForm]],
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox["\n\n",
    FontSize->12],
  StyleBox["So in our example:",
    FontFamily->"Times",
    FontSize->12]
}], "Text",
  TextAlignment->Left,
  FontFamily->"Courier",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(ChineseRemainderTheorem[{14, \ 6}, \ {24, \ 31}]\)], "Input"],

Cell[BoxData[
    \(254\)], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
WindowSize->{637, 759},
WindowMargins->{{-9, Automatic}, {Automatic, 8}},
MacintoshSystemPageSetup->"\<\
00P0001804P000000]/2@?oWonh2o`9B7`<5:0?l0040004/0B`000002nL9H04/
02d5X5k/02H20@4101P00BL?00400@0000000000000000010000000000000000
0000000000000002000000@210D00000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 54, 0, 50, "Section"],
Cell[1796, 53, 369, 10, 82, "Text"],

Cell[CellGroupData[{
Cell[2190, 67, 51, 1, 27, "Input"],
Cell[2244, 70, 35, 1, 26, "Output"]
}, Open  ]],
Cell[2294, 74, 71, 2, 30, "Text"],

Cell[CellGroupData[{
Cell[2390, 80, 49, 1, 27, "Input"],
Cell[2442, 83, 35, 1, 26, "Output"]
}, Open  ]],
Cell[2492, 87, 71, 2, 30, "Text"],

Cell[CellGroupData[{
Cell[2588, 93, 47, 1, 27, "Input"],
Cell[2638, 96, 35, 1, 26, "Output"]
}, Open  ]],
Cell[2688, 100, 369, 15, 32, "Text"],

Cell[CellGroupData[{
Cell[3082, 119, 55, 1, 27, "Input"],
Cell[3140, 122, 35, 1, 26, "Output"]
}, Open  ]],
Cell[3190, 126, 326, 15, 32, "Text"],

Cell[CellGroupData[{
Cell[3541, 145, 45, 1, 27, "Input"],
Cell[3589, 148, 71, 1, 26, "Output"]
}, Open  ]],
Cell[3675, 152, 219, 7, 32, "Text"],

Cell[CellGroupData[{
Cell[3919, 163, 46, 1, 27, "Input"],
Cell[3968, 166, 91, 1, 26, "Output"]
}, Open  ]],
Cell[4074, 170, 118, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[4217, 177, 57, 1, 27, "Input"],
Cell[4277, 180, 35, 1, 26, "Output"]
}, Open  ]],
Cell[4327, 184, 309, 9, 48, "Text"],

Cell[CellGroupData[{
Cell[4661, 197, 243, 4, 59, "Input"],
Cell[4907, 203, 419, 10, 55, "Output"]
}, Open  ]],
Cell[5341, 216, 29, 0, 30, "Text"],
Cell[5373, 218, 160, 6, 30, "Text"],
Cell[5536, 226, 23, 0, 30, "Text"],
Cell[5562, 228, 137, 5, 30, "Text"],
Cell[5702, 235, 26, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[5753, 239, 56, 1, 27, "Input"],
Cell[5812, 242, 35, 1, 26, "Output"]
}, Open  ]],
Cell[5862, 246, 104, 4, 46, "Text"],
Cell[5969, 252, 1002, 44, 54, "Text"],

Cell[CellGroupData[{
Cell[6996, 300, 54, 1, 27, "Input"],
Cell[7053, 303, 50, 1, 26, "Output"]
}, Open  ]],
Cell[7118, 307, 483, 19, 47, "Text"],

Cell[CellGroupData[{
Cell[7626, 330, 56, 1, 27, "Input"],
Cell[7685, 333, 51, 1, 26, "Output"]
}, Open  ]],
Cell[7751, 337, 565, 16, 82, "Text"],
Cell[8319, 355, 594, 26, 112, "Text"],
Cell[8916, 383, 53, 0, 30, "Text"],
Cell[8972, 385, 71, 1, 27, "Input"],
Cell[9046, 388, 1911, 76, 113, "Text"],

Cell[CellGroupData[{
Cell[10982, 468, 81, 1, 27, "Input"],
Cell[11066, 471, 37, 1, 26, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

