(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10860,        465]*)
(*NotebookOutlinePosition[     11706,        492]*)
(*  CellTagsIndexPosition[     11662,        488]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Chapter 14: Calculations", "Section"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has a package \"Algebra\" with a function ",
  StyleBox["PolynomialExtendedGCD",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " which calculates (f, g) for two polynomials f and g, as well as \
polynomials s and t such that"
}], "Text",
  FontSize->14],

Cell["(f, g) = sf + tg .", "Text",
  TextAlignment->Center,
  FontSize->14],

Cell["First load the package:", "Text",
  FontSize->14],

Cell[BoxData[
    \(<< Algebra`PolynomialExtendedGCD`\)], "Input",
  FontSize->14],

Cell[TextData[{
  "If we take   f = ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(x\^3\),
            "TraditionalForm"], "+", \(x\^2\)}], TraditionalForm]]],
  "+x+1 , g = ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(x\^4\),
            "TraditionalForm"], "+", \(x\^3\)}], TraditionalForm]]],
  "+x+1  \[Element] \[DoubleStruckCapitalQ][x] , we obtain"
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(PolynomialExtendedGCD[x^3 + x^2 + x + 1, \ 
      x^4 + x^3 + x + 1]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \({1 + x, {1\/2 - x\/2 - x\^2\/2, 1\/2 + x\/2}}\)], "Output"]
}, Open  ]],

Cell["Thus", "Text",
  FontSize->14],

Cell[TextData[{
  "( ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(x\^3\),
            "TraditionalForm"], "+", \(x\^2\)}], TraditionalForm]]],
  "+x+1, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(x\^4\),
            "TraditionalForm"], "+", \(x\^3\)}], TraditionalForm]]],
  "+x+1 ) = x+1"
}], "Text",
  TextAlignment->Center,
  FontSize->14],

Cell["and", "Text",
  FontSize->14],

Cell[TextData[{
  "x+1  =  (",
  Cell[BoxData[
      \(1\/2 - x\/2 - x\^2\/2\)]],
  ")( ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(x\^3\),
            "TraditionalForm"], "+", \(x\^2\)}], TraditionalForm]]],
  "+x+1 ) + (",
  Cell[BoxData[
      \(1\/2 + x\/2\)]],
  ")( ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(x\^4\),
            "TraditionalForm"], "+", \(x\^3\)}], TraditionalForm]]],
  "+x+1 )"
}], "Text",
  TextAlignment->Center,
  FontSize->14],

Cell[TextData[{
  "The function can also calculate in ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalF]\_p\)]],
  " . Here is example 14.1:"
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(PolynomialExtendedGCD[x^4\  + \ x^3\  + \ x^2\  + \ 3  x\  + \ 2, \ 
      x^5\  - \ x^4\  - \ x^3\  + \ 2  x^2\  - \ x\  - \ 2, \ 
      Modulus -> 11]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \({1 + x, {8 + 3\ x + 6\ x\^2 + 4\ x\^3, 2 + 8\ x + 7\ x\^2}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["\tMathematica",
    FontSlant->"Italic"],
  " is very useful for a calculation like example 14.5. We have"
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(f\  = \ 3 + x + 6\ x\^2 + 2\ x\^3 + 4\ x\^4 + 5\ x\^5 + x\^6\)], "Input",\

  FontSize->14],

Cell[BoxData[
    \(3 + x + 6\ x\^2 + 2\ x\^3 + 4\ x\^4 + 5\ x\^5 + x\^6\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "To compute ",
  Cell[BoxData[
      \(TraditionalForm\`x\^7\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x\^14\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x\^21\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x\^28\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`x\^35\)]],
  " in term of the basis {1, x, ..., ",
  Cell[BoxData[
      \(TraditionalForm\`x\^6\)]],
  "} of V, we can use the function ",
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["PolynomialMod",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "which reduces a polynomial modulo a natural number ",
  StyleBox["n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and a\npolynomial ",
  StyleBox["f",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(PolynomialMod[\ x^7, {f, 7}]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(1 + 2\ x + x\^2 + 4\ x\^3 + 4\ x\^4\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PolynomialMod[\ x^14, {f, 7}]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(3 + 4\ x + 3\ x\^2 + 3\ x\^3 + 2\ x\^4 + 3\ x\^5\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PolynomialMod[\ x^21, {f, 7}]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(3 + 3\ x + x\^2 + x\^3 + x\^4 + 4\ x\^5\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PolynomialMod[\ x^28, {f, 7}]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(3 + 5\ x\^2 + 5\ x\^3 + 2\ x\^4\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PolynomialMod[\ x^35, {f, 7}]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(3 + 3\ x\^2 + 5\ x\^4 + 5\ x\^5\)], "Output"]
}, Open  ]],

Cell["Then", "Text",
  FontSize->14],

Cell[BoxData[
    \(\(A\  = \ 
        Transpose[{{1, 0, 0, 0, 0, 0}, {1, 2, 1, 4, 4, 0}, {3, 4, 3, 3, 2, 
              3}, {3, 3, 1, 1, 1, 4}, {3, 0, 5, 5, 2, 0}, {3, 0, 3, 0, 5, 
              5}}];\)\)], "Input",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixForm[A]\)], "Input",
  FontSize->14],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "1", "3", "3", "3", "3"},
            {"0", "2", "4", "3", "0", "0"},
            {"0", "1", "3", "1", "5", "3"},
            {"0", "4", "3", "1", "5", "0"},
            {"0", "4", "2", "1", "2", "5"},
            {"0", "0", "3", "4", "0", "5"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "To compute the kernel of  ",
  StyleBox["A-I",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " we can use the function ",
  StyleBox["Nullspace",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullSpace[A - IdentityMatrix[6], \ Modulus -> 7]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \({{0, 3, 6, 5, 1, 1}, {1, 0, 0, 0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell["Now we set", "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(g\  = \ 3  x\  + \ 6  x^2\  + \ 5  x^3\  + \ x^4\  + \ x^5\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(3\ x + 6\ x\^2 + 5\ x\^3 + x\^4 + x\^5\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "To check the greatest common divisors ",
  StyleBox["(g+a,f)",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " for  a \[Element]  ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalF]\_7\)]],
  ", we use the function ",
  StyleBox["PolynomialGCD",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(PolynomialGCD[g + 4, f, Modulus -> 7]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(5 + 3\ x + x\^2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PolynomialGCD[g + 5, f, Modulus -> 7]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(2 + 6\ x + 2\ x\^3 + x\^4\)], "Output"]
}, Open  ]],

Cell["\<\
We check the greatest common divisor of this quartic with its \
derivative:\
\>", "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(PolynomialGCD[2 + 6\ x + 2\ x\^3 + x\^4, 
      PolynomialMod[D[2 + 6\ x + 2\ x\^3 + x\^4, x], 7], 
      Modulus -> 7]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(3 + x + x\^2\)], "Output"]
}, Open  ]],

Cell["Lastly, we verify the factorization.", "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(PolynomialMod[Expand[\((5 + 3\ x + x\^2)\)*\((3 + x + x\^2)\)^2], 
      7]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(3 + x + 6\ x\^2 + 2\ x\^3 + 4\ x\^4 + 5\ x\^5 + x\^6\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " does have a built-in function which implements Berlekamp's algorithm:"
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[
      x^6\  + \ 5  x^5\  + \ 4  x^4\  + \ 2  x^3\  + \ 6  x^2\  + \ x\  + \ 
        3, Modulus \[Rule] 7]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(\((3 + x + x\^2)\)\^2\ \((5 + 3\ x + x\^2)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We can use this to check that  ",
  Cell[BoxData[
      \(TraditionalForm\`x\^5\)]],
  "- 5x + 12 is irreducible modulo 7:"
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[x^5\  - \ 5  x\  + \ 12, \ Modulus \[Rule] 7]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(5 + 2\ x + x\^5\)], "Output"]
}, Open  ]],

Cell["You can also factor polynomials over Q:", "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[
      x^6\  + \ x^5\  + \ 4  x^4\  + \ 2  x^3\  + \ 6  x^2\  + \ x\  + \ 
        3]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(\((1 + x\^2)\)\ \((3 + x + 3\ x\^2 + x\^3 + x\^4)\)\)], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
WindowSize->{520, 740},
WindowMargins->{{Automatic, 196}, {Automatic, 21}},
MacintoshSystemPageSetup->"\<\
00P0001804P000000]/2@?oWonh2o`9B7`<5:0?l0040004/0B`000002nL9H04/
02d5X5k/02H20@4101P00BL?00400@0000000000000000010000000000000000
0000000000000002000000@210D00000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 43, 0, 50, "Section"],
Cell[1785, 53, 333, 10, 69, "Text"],
Cell[2121, 65, 75, 2, 32, "Text"],
Cell[2199, 69, 55, 1, 32, "Text"],
Cell[2257, 72, 82, 2, 28, "Input"],
Cell[2342, 76, 433, 15, 32, "Text"],

Cell[CellGroupData[{
Cell[2800, 95, 117, 3, 46, "Input"],
Cell[2920, 100, 79, 1, 43, "Output"]
}, Open  ]],
Cell[3014, 104, 36, 1, 32, "Text"],
Cell[3053, 107, 395, 16, 32, "Text"],
Cell[3451, 125, 35, 1, 32, "Text"],
Cell[3489, 128, 510, 22, 38, "Text"],
Cell[4002, 152, 186, 6, 32, "Text"],

Cell[CellGroupData[{
Cell[4213, 162, 201, 4, 64, "Input"],
Cell[4417, 168, 93, 1, 28, "Output"]
}, Open  ]],
Cell[4525, 172, 162, 5, 33, "Text"],

Cell[CellGroupData[{
Cell[4712, 181, 111, 3, 31, "Input"],
Cell[4826, 186, 86, 1, 28, "Output"]
}, Open  ]],
Cell[4927, 190, 870, 37, 88, "Text"],

Cell[CellGroupData[{
Cell[5822, 231, 77, 2, 28, "Input"],
Cell[5902, 235, 69, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6008, 241, 78, 2, 28, "Input"],
Cell[6089, 245, 82, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6208, 251, 78, 2, 28, "Input"],
Cell[6289, 255, 73, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6399, 261, 78, 2, 28, "Input"],
Cell[6480, 265, 65, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6582, 271, 78, 2, 28, "Input"],
Cell[6663, 275, 65, 1, 28, "Output"]
}, Open  ]],
Cell[6743, 279, 36, 1, 32, "Text"],
Cell[6782, 282, 232, 5, 82, "Input"],

Cell[CellGroupData[{
Cell[7039, 291, 62, 2, 28, "Input"],
Cell[7104, 295, 405, 10, 111, "Output"]
}, Open  ]],
Cell[7524, 308, 258, 11, 32, "Text"],

Cell[CellGroupData[{
Cell[7807, 323, 97, 2, 28, "Input"],
Cell[7907, 327, 74, 1, 26, "Output"]
}, Open  ]],
Cell[7996, 331, 42, 1, 32, "Text"],

Cell[CellGroupData[{
Cell[8063, 336, 107, 2, 28, "Input"],
Cell[8173, 340, 72, 1, 28, "Output"]
}, Open  ]],
Cell[8260, 344, 374, 14, 50, "Text"],

Cell[CellGroupData[{
Cell[8659, 362, 86, 2, 28, "Input"],
Cell[8748, 366, 49, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8834, 372, 86, 2, 28, "Input"],
Cell[8923, 376, 59, 1, 28, "Output"]
}, Open  ]],
Cell[8997, 380, 115, 4, 32, "Text"],

Cell[CellGroupData[{
Cell[9137, 388, 168, 4, 69, "Input"],
Cell[9308, 394, 46, 1, 28, "Output"]
}, Open  ]],
Cell[9369, 398, 68, 1, 32, "Text"],

Cell[CellGroupData[{
Cell[9462, 403, 124, 3, 49, "Input"],
Cell[9589, 408, 86, 1, 28, "Output"]
}, Open  ]],
Cell[9690, 412, 170, 5, 51, "Text"],

Cell[CellGroupData[{
Cell[9885, 421, 163, 4, 46, "Input"],
Cell[10051, 427, 78, 1, 29, "Output"]
}, Open  ]],
Cell[10144, 431, 170, 6, 32, "Text"],

Cell[CellGroupData[{
Cell[10339, 441, 101, 2, 28, "Input"],
Cell[10443, 445, 49, 1, 28, "Output"]
}, Open  ]],
Cell[10507, 449, 71, 1, 32, "Text"],

Cell[CellGroupData[{
Cell[10603, 454, 141, 4, 28, "Input"],
Cell[10747, 460, 85, 1, 28, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

