(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     13725,        521]*)
(*NotebookOutlinePosition[     14571,        548]*)
(*  CellTagsIndexPosition[     14527,        544]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Chapter 4:Software and Calculations", "Section"],

Cell[TextData[{
  "The package \"Groups.m\" also allows you to make calculations with linear \
groups over a field ",
  Cell[BoxData[
      \(TraditionalForm\`F\_p\)]],
  ". After loading the package, you must first choose a prime with the \
function ",
  StyleBox["ChoosePrime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " . For example\t\t "
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(ChoosePrime[11]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(11\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "All your calculations will then be modulo this prime. You can change the \
prime at any time, but if you do not make a choice none of the functions will \
evaluate. Matrices are usually represented in  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " as lists of lists. In this package, however, such a representation is \
wrapped with ",
  StyleBox["L[] ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "in order to give a mechanism to reduce modulo the chosen prime at each \
step in the calculations. (As well it avoids confusion with permutations in \
cycle notation which are also represented in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "  as lists of lists). For example, the general  2x2",
  StyleBox[" ",
    FontFamily->"cmti12",
    FontSize->14],
  " matrix"
}], "Text",
  FontSize->14],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"a", "b"},
            {"c", "d"}
            }], ")"}], TextForm]], "Text",
  TextAlignment->Center,
  FontSize->14],

Cell[TextData[{
  "which is usually represented in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " as "
}], "Text",
  FontSize->14],

Cell[TextData[StyleBox["{{a, b}, {c, d}}",
  FontFamily->"Courier",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Center,
  FontSize->14],

Cell["is represented in this package as", "Text",
  FontSize->14],

Cell[TextData[StyleBox["L[{a, b}, {c, d}]",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Center,
  FontFamily->"Courier",
  FontSize->14],

Cell["\<\
The same functions you used with permutation groups are defined for \
linear groups. For example if\
\>", "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(a\  = \ \ L[{1, 2}, {3, 4}]\)], "Input",
  FontSize->14],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "2"},
            {"3", "4"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(b\ \  = \ \ L[{6, 3}, {7, 5}]\)], "Input",
  FontSize->14],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"6", "3"},
            {"7", "5"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell["then", "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(Inverse[a]\)], "Input",
  FontSize->14],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"9", "1"},
            {"7", "5"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(a\  . \ b\)], "Input",
  FontSize->14],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"9", "2"},
            {"2", "7"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell["Now suppose", "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(ChoosePrime[7]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(7\)], "Output"]
}, Open  ]],

Cell["and", "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(G\  = \ {\ L[{1, 1}, {1, 2}], L[{2, 3}, {4, 1}], \ L[{2, 6}, {6, 1}], 
        L[{1, 0}, {0, 1}], \ L[{2, 1}, {6, 4}]\ }\)], "Input",
  FontSize->14],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "1"},
                {"1", "2"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"2", "3"},
                {"4", "1"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"2", "6"},
                {"6", "1"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "0"},
                {"0", "1"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"2", "1"},
                {"6", "4"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output"]
}, Open  ]],

Cell["then", "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(Inverse[G]\)], "Input",
  FontSize->14],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"2", "6"},
                {"6", "1"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"2", "1"},
                {"6", "4"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "1"},
                {"1", "2"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "0"},
                {"0", "1"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"2", "3"},
                {"4", "1"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "So ",
  StyleBox["G",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is closed under taking inverses. Let's check whether it is closed under \
products:"
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(G . G\)], "Input",
  FontSize->14],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "5"},
                {"2", "5"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "0"},
                {"0", "1"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "1"},
                {"0", "4"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "1"},
                {"1", "2"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "5"},
                {"0", "2"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"2", "1"},
                {"6", "4"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"2", "2"},
                {"5", "6"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"2", "3"},
                {"3", "5"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"2", "3"},
                {"4", "1"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"2", "6"},
                {"6", "1"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"3", "4"},
                {"3", "0"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"3", "6"},
                {"1", "1"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"3", "6"},
                {"1", "5"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"5", "1"},
                {"5", "6"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"5", "4"},
                {"4", "2"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"5", "5"},
                {"4", "3"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"6", "4"},
                {"3", "5"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "You see immediately that the product of  ",
  StyleBox["L[{1,1},{1,2}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "  with itself is not in ",
  StyleBox["G",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". So ",
  StyleBox["G",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is not a linear group.\n\n\tWe can verify that  GL(2,  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[DoubleStruckCapitalF]\_5\)\()\)\)\)]],
  "  is generated by the three matrices above. First we change the chosen \
prime to 5."
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(ChoosePrime[5]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(5\)], "Output"]
}, Open  ]],

Cell["Let", "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(H\  = \ 
      Group[\ L[{2, 0}, {0, 1}], \ L[{0, 1}, {1, 0}], \ 
        L[{1, 1}, {0, 1}]\ ]\)], "Input",
  FontSize->14],

Cell[BoxData[
    RowBox[{"\[LeftAngleBracket]", 
      RowBox[{
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"2", "0"},
                {"0", "1"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "1"},
                {"1", "0"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "1"},
                {"0", "1"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)]}], "\[RightAngleBracket]"}]], "Output"]
}, Open  ]],

Cell["Now we check:", "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(Order[H]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(480\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This is indeed ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(4\^2\)\)\)]],
  "\[CenterDot] 5 \[CenterDot]6 . Can you find three matrices which generate\n\
GL(2, ",
  Cell[BoxData[
      \(TraditionalForm\`F\_7\)]],
  ") ?  GL(2, ",
  Cell[BoxData[
      \(TraditionalForm\`F\_11\)]],
  ") ?"
}], "Text",
  FontSize->14]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
WindowSize->{520, 740},
WindowMargins->{{Automatic, 296}, {Automatic, 23}},
MacintoshSystemPageSetup->"\<\
00P0001804P000000]/2@?oWonh2o`9B7`<5:0?l0040004/0B`000002nL9H04/
02d5X5k/02H20@4101P00BL?00400@0000000000000000010000000000000000
0000000000000002000000@210D00000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 54, 0, 50, "Section"],
Cell[1796, 53, 383, 12, 68, "Text"],

Cell[CellGroupData[{
Cell[2204, 69, 64, 2, 28, "Input"],
Cell[2271, 73, 36, 1, 26, "Output"]
}, Open  ]],
Cell[2322, 77, 850, 22, 145, "Text"],
Cell[3175, 101, 186, 7, 49, "Text"],
Cell[3364, 110, 142, 6, 33, "Text"],
Cell[3509, 118, 140, 4, 32, "Text"],
Cell[3652, 124, 65, 1, 32, "Text"],
Cell[3720, 127, 141, 4, 32, "Text"],
Cell[3864, 133, 139, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[4028, 141, 76, 2, 28, "Input"],
Cell[4107, 145, 189, 6, 39, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4333, 156, 78, 2, 28, "Input"],
Cell[4414, 160, 189, 6, 39, "Output"]
}, Open  ]],
Cell[4618, 169, 36, 1, 32, "Text"],

Cell[CellGroupData[{
Cell[4679, 174, 59, 2, 28, "Input"],
Cell[4741, 178, 189, 6, 39, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4967, 189, 58, 2, 28, "Input"],
Cell[5028, 193, 189, 6, 39, "Output"]
}, Open  ]],
Cell[5232, 202, 43, 1, 32, "Text"],

Cell[CellGroupData[{
Cell[5300, 207, 63, 2, 28, "Input"],
Cell[5366, 211, 35, 1, 26, "Output"]
}, Open  ]],
Cell[5416, 215, 35, 1, 32, "Text"],

Cell[CellGroupData[{
Cell[5476, 220, 169, 3, 64, "Input"],
Cell[5648, 225, 1035, 32, 39, "Output"]
}, Open  ]],
Cell[6698, 260, 36, 1, 32, "Text"],

Cell[CellGroupData[{
Cell[6759, 265, 59, 2, 28, "Input"],
Cell[6821, 269, 1035, 32, 39, "Output"]
}, Open  ]],
Cell[7871, 304, 209, 8, 50, "Text"],

Cell[CellGroupData[{
Cell[8105, 316, 54, 2, 28, "Input"],
Cell[8162, 320, 3375, 104, 101, "Output"]
}, Open  ]],
Cell[11552, 427, 585, 19, 104, "Text"],

Cell[CellGroupData[{
Cell[12162, 450, 63, 2, 28, "Input"],
Cell[12228, 454, 35, 1, 26, "Output"]
}, Open  ]],
Cell[12278, 458, 35, 1, 32, "Text"],

Cell[CellGroupData[{
Cell[12338, 463, 143, 4, 46, "Input"],
Cell[12484, 469, 682, 20, 39, "Output"]
}, Open  ]],
Cell[13181, 492, 45, 1, 32, "Text"],

Cell[CellGroupData[{
Cell[13251, 497, 57, 2, 28, "Input"],
Cell[13311, 501, 37, 1, 26, "Output"]
}, Open  ]],
Cell[13363, 505, 346, 13, 50, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

